import {Component} from '@angular/core';
import {SearchCustomFilter} from "../../../openaireLibrary/searchPages/searchUtils/searchUtils.class";
import {ActivatedRoute, Router} from "@angular/router";
import {StakeholderService} from "../../../openaireLibrary/monitor/services/stakeholder.service";
import {Subscriber} from "rxjs";

@Component({
  selector: 'monitor-search-projects',
  template: `
    <div id="page_content">
      <search-projects *ngIf="initialized"
                       [customFilter]=customFilter [hasPrefix]="false"
                       [includeOnlyResultsAndFilter]="false" >
      </search-projects>
    </div>
  `
  
})
export class MonitorSearchProjectsComponent {
  customFilter: SearchCustomFilter = null;
  initialized: boolean = false;

  constructor(private route: ActivatedRoute,
              private router: Router,
              private stakeholderService: StakeholderService) {
  }
  subscriptions = [];
  ngOnDestroy() {
    this.subscriptions.forEach(subscription => {
      if (subscription instanceof Subscriber) {
        subscription.unsubscribe();
      }
    });
  }

  ngOnInit() {
    this.subscriptions.push(this.route.params.subscribe(params => {
      if (params['stakeholder']) {
        this.subscriptions.push(this.stakeholderService.getStakeholderAsObservable().subscribe(stakeholder => {
          if (stakeholder) {
            if (stakeholder.type === "funder") {
              let value = stakeholder.index_id+"||"+stakeholder.index_name+"||"+stakeholder.index_shortName;
              this.customFilter = new SearchCustomFilter("Funder", "funder", value, "");
              this.customFilter.isHiddenFilter = false;
              this.customFilter.promptToAddFilter = true;
            } else if (stakeholder.type === "organization") {
              let value = stakeholder.index_id;
              this.customFilter = new SearchCustomFilter("Organization", "relorganizationid", value, "");
              this.customFilter.isHiddenFilter = false;
              this.customFilter.promptToAddFilter = true;
            } else if (stakeholder.type === "ri") {
              this.navigateToError();
            }
            this.initialized = true;

          }
        }));
      }
    }));
  }
  
  navigateToError() {
    this.router.navigate(['/error'], {queryParams: {'page': this.router.url}});
  }
}
